OC.L10N.register(
    "spreed",
    {
    "Everyone" : "Hamı",
    "None" : "Heç bir",
    "User" : "User",
    "Disabled" : "Dayandırılıb",
    "Users" : "İstifadəçilər",
    "Name" : "Ad",
    "Saved" : "Saxlanıldı",
    "Copy link" : "linki nüsxələ",
    "Favorite" : "İstəkli",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Contacts" : "Əlaqələr",
    "Loading" : "Loading",
    "Groups" : "Qruplar",
    "Error" : "Səhv",
    "Close" : "Bağla",
    "Reply" : "Cavab",
    "Today" : "Bu gün",
    "Yesterday" : "Dünən",
    "guest" : "Qonaq",
    "Settings" : "Quraşdırmalar",
    "Edit" : "Dəyişiklik et",
    "Share link" : "Linki yayımla",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "The password is wrong. Try again." : "Şifrə yalnışdır. Yenidən cəhd edin.",
    "Password" : "Şifrə",
    "Android app" : "Android proqramı",
    "iOS app" : "iOS proqramı",
    "Cancel" : "Dayandır",
    "Change password" : "Şifrəni dəyiş",
    "Rename" : "Adı dəyiş",
    "Send" : "Göndər",
    "Share" : "Paylaş",
    "Favorited" : "İstəkləndi"
},
"nplurals=2; plural=(n != 1);");
